@@ -12,7 +12,7 @@ use warnings;
 
 package App::Magpie;
 BEGIN {
-  $App::Magpie::VERSION = '1.110410';
+  $App::Magpie::VERSION = '1.110470';
 }
 # ABSTRACT: Mageia Perl Integration Easy
 
@@ -151,17 +151,17 @@ sub fixspec {
         my %br_from_meta;
         if ( $meta->{"meta-spec"}{version} < 2 ) {
             %br_from_meta = (
-                %{ $meta->{configure_requires} },
-                %{ $meta->{build_requires} },
-                %{ $meta->{requires} },
+                %{ $meta->{configure_requires} // {} },
+                %{ $meta->{build_requires}     // {} },
+                %{ $meta->{requires}           // {} },
             );
         } else {
             my $prereqs = $meta->{prereqs};
             %br_from_meta = (
-                %{ $prereqs->{configure}{requires} },
-                %{ $prereqs->{build}{requires} },
-                %{ $prereqs->{test}{requires} },
-                %{ $prereqs->{runtime}{requires} },
+                %{ $prereqs->{configure}{requires} // {} },
+                %{ $prereqs->{build}{requires}     // {} },
+                %{ $prereqs->{test}{requires}      // {} },
+                %{ $prereqs->{runtime}{requires}   // {} },
             );
         }
 
@@ -378,7 +378,7 @@ App::Magpie - Mageia Perl Integration Easy
 
 =head1 VERSION
 
-version 1.110410
+version 1.110470
 
 =head1 DESCRIPTION
 
@@ -482,7 +482,7 @@ L<http://cpanratings.perl.org/d/App-Magpie>
 
 =head1 AUTHOR
 
-  Jerome Quelin <jquelin@gmail.com>
+Jerome Quelin <jquelin@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
